@@ -15,7 +15,7 @@ import (
 
 	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/consul/api"
-	"github.com/hashicorp/consul/lib"
+	"github.com/hashicorp/consul/internal/gossip/librtt"
 	"github.com/hashicorp/consul/sdk/testutil"
 	"github.com/hashicorp/consul/sdk/testutil/retry"
 	"github.com/hashicorp/consul/testrpc"
@@ -193,8 +193,8 @@ func TestHealth_ChecksInState_DistanceSort(t *testing.T) {
 		t.Fatalf("err: %v", err)
 	}
 	updates := structs.Coordinates{
-		{Node: "foo", Coord: lib.GenerateCoordinate(1 * time.Millisecond)},
-		{Node: "bar", Coord: lib.GenerateCoordinate(2 * time.Millisecond)},
+		{Node: "foo", Coord: librtt.GenerateCoordinate(1 * time.Millisecond)},
+		{Node: "bar", Coord: librtt.GenerateCoordinate(2 * time.Millisecond)},
 	}
 	if err := s1.fsm.State().CoordinateBatchUpdate(3, updates); err != nil {
 		t.Fatalf("err: %v", err)
@@ -482,8 +482,8 @@ func TestHealth_ServiceChecks_DistanceSort(t *testing.T) {
 		t.Fatalf("err: %v", err)
 	}
 	updates := structs.Coordinates{
-		{Node: "foo", Coord: lib.GenerateCoordinate(1 * time.Millisecond)},
-		{Node: "bar", Coord: lib.GenerateCoordinate(2 * time.Millisecond)},
+		{Node: "foo", Coord: librtt.GenerateCoordinate(1 * time.Millisecond)},
+		{Node: "bar", Coord: librtt.GenerateCoordinate(2 * time.Millisecond)},
 	}
 	if err := s1.fsm.State().CoordinateBatchUpdate(3, updates); err != nil {
 		t.Fatalf("err: %v", err)
@@ -969,8 +969,8 @@ func TestHealth_ServiceNodes_DistanceSort(t *testing.T) {
 		t.Fatalf("err: %v", err)
 	}
 	updates := structs.Coordinates{
-		{Node: "foo", Coord: lib.GenerateCoordinate(1 * time.Millisecond)},
-		{Node: "bar", Coord: lib.GenerateCoordinate(2 * time.Millisecond)},
+		{Node: "foo", Coord: librtt.GenerateCoordinate(1 * time.Millisecond)},
+		{Node: "bar", Coord: librtt.GenerateCoordinate(2 * time.Millisecond)},
 	}
 	if err := s1.fsm.State().CoordinateBatchUpdate(3, updates); err != nil {
 		t.Fatalf("err: %v", err)
