@@ -9,6 +9,8 @@ import (
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
+	"github.com/hashicorp/go-hclog"
+
 	"github.com/hashicorp/consul/acl"
 	"github.com/hashicorp/consul/internal/resource"
 	"github.com/hashicorp/consul/proto-public/pbresource"
@@ -37,3 +39,25 @@ func checkV2Tenancy(useV2Tenancy bool, rtype *pbresource.Type) error {
 	}
 	return nil
 }
+
+type Config struct {
+	Logger   hclog.Logger
+	Registry Registry
+
+	// Backend is the storage backend that will be used for resource persistence.
+	Backend     Backend
+	ACLResolver ACLResolver
+	// TenancyBridge temporarily allows us to use V1 implementations of
+	// partitions and namespaces until V2 implementations are available.
+	TenancyBridge TenancyBridge
+
+	// UseV2Tenancy is true if the "v2tenancy" experiment is active, false otherwise.
+	// Attempts to create v2 tenancy resources (partition or namespace) will fail when the
+	// flag is false.
+	UseV2Tenancy bool
+}
+
+// FeatureCheck does not apply to the community edition.
+func (s *Server) FeatureCheck(reg *resource.Registration) error {
+	return nil
+}
