@@ -96,12 +96,12 @@ func TestGenerateComputedRoutes(t *testing.T) {
 			return rtest.MustDecode[*pbmesh.DestinationPolicy](t, policy)
 		}
 
-		newFailPolicy := func(name string, data *pbcatalog.FailoverPolicy) *types.DecodedFailoverPolicy {
-			policy := rtest.Resource(pbcatalog.FailoverPolicyType, name).
+		newFailPolicy := func(name string, data *pbcatalog.ComputedFailoverPolicy) *types.DecodedComputedFailoverPolicy {
+			policy := rtest.Resource(pbcatalog.ComputedFailoverPolicyType, name).
 				WithTenancy(tenancy).
 				WithData(t, data).Build()
 			rtest.ValidateAndNormalize(t, registry, policy)
-			return rtest.MustDecode[*pbcatalog.FailoverPolicy](t, policy)
+			return rtest.MustDecode[*pbcatalog.ComputedFailoverPolicy](t, policy)
 		}
 
 		backendName := func(name, port string) string {
@@ -1606,11 +1606,18 @@ func TestGenerateComputedRoutes(t *testing.T) {
 			failoverPolicy := &pbcatalog.FailoverPolicy{
 				Config: &pbcatalog.FailoverConfig{
 					Destinations: []*pbcatalog.FailoverDestination{
-						{Ref: barServiceRef},
+						{Ref: barServiceRef},  // port is not supported in non-ported config
 						{Ref: deadServiceRef}, // no service
 					},
 				},
 			}
+
+			simplifiedFailoverPolicy := catalog.SimplifyFailoverPolicy(fooServiceData, failoverPolicy)
+
+			computedFailoverPolicy := &pbcatalog.ComputedFailoverPolicy{
+				PortConfigs:     simplifiedFailoverPolicy.PortConfigs,
+				BoundReferences: []*pbresource.Reference{barServiceRef},
+			}
 			portFailoverConfig := &pbmesh.ComputedFailoverConfig{
 				Destinations: []*pbmesh.ComputedFailoverDestination{
 					{BackendTarget: backendName("bar", "http")},
@@ -1625,7 +1632,7 @@ func TestGenerateComputedRoutes(t *testing.T) {
 					newService("foo", fooServiceData),
 					newService("bar", barServiceData),
 					newHTTPRoute("api-http-route1", httpRoute1),
-					newFailPolicy("foo", failoverPolicy),
+					newFailPolicy("foo", computedFailoverPolicy),
 				)
 
 			expect := []*ComputedRoutesResult{{
@@ -1633,7 +1640,7 @@ func TestGenerateComputedRoutes(t *testing.T) {
 				OwnerID: apiServiceID,
 				Data: &pbmesh.ComputedRoutes{
 					BoundReferences: []*pbresource.Reference{
-						newRef(pbcatalog.FailoverPolicyType, "foo", tenancy),
+						newRef(pbcatalog.ComputedFailoverPolicyType, "foo", tenancy),
 						apiServiceRef,
 						barServiceRef,
 						fooServiceRef,
@@ -1860,9 +1867,17 @@ func TestGenerateComputedRoutes(t *testing.T) {
 										},
 									},
 								}
+
+								simplifiedFailoverPolicy := catalog.SimplifyFailoverPolicy(fooServiceData, failoverPolicy)
+
+								computedFailoverPolicy := &pbcatalog.ComputedFailoverPolicy{
+									PortConfigs:     simplifiedFailoverPolicy.PortConfigs,
+									BoundReferences: []*pbresource.Reference{barServiceRef},
+								}
+
 								// Test ported config if used in test case
 								if configKeyPortFoo != "" {
-									failoverPolicy = &pbcatalog.FailoverPolicy{
+									failoverPolicy := &pbcatalog.FailoverPolicy{
 										PortConfigs: map[string]*pbcatalog.FailoverConfig{
 											configKeyPortFoo: {
 												Destinations: []*pbcatalog.FailoverDestination{
@@ -1872,6 +1887,13 @@ func TestGenerateComputedRoutes(t *testing.T) {
 											},
 										},
 									}
+
+									simplifiedFailoverPolicy = catalog.SimplifyFailoverPolicy(fooServiceData, failoverPolicy)
+
+									computedFailoverPolicy = &pbcatalog.ComputedFailoverPolicy{
+										PortConfigs:     simplifiedFailoverPolicy.PortConfigs,
+										BoundReferences: []*pbresource.Reference{barServiceRef},
+									}
 								}
 								expectedPortFailoverConfig := &pbmesh.ComputedFailoverConfig{
 									Destinations: []*pbmesh.ComputedFailoverDestination{
@@ -1887,7 +1909,7 @@ func TestGenerateComputedRoutes(t *testing.T) {
 										newService("foo", fooServiceData),
 										newService("bar", barServiceData),
 										newHTTPRoute("api-http-route1", httpRoute1),
-										newFailPolicy("foo", failoverPolicy),
+										newFailPolicy("foo", computedFailoverPolicy),
 									)
 
 								// Same result as non-virtual-port variant of test
@@ -1896,7 +1918,7 @@ func TestGenerateComputedRoutes(t *testing.T) {
 									OwnerID: apiServiceID,
 									Data: &pbmesh.ComputedRoutes{
 										BoundReferences: []*pbresource.Reference{
-											newRef(pbcatalog.FailoverPolicyType, "foo", tenancy),
+											newRef(pbcatalog.ComputedFailoverPolicyType, "foo", tenancy),
 											apiServiceRef,
 											barServiceRef,
 											fooServiceRef,
