@@ -115,7 +115,7 @@ func TestBuildLocalApp(t *testing.T) {
 				})
 
 				actual := protoToJSON(t, proxyTmpl)
-				expected := JSONToProxyTemplate(t, golden.GetBytes(t, actual, name+"-"+tenancy.Partition+"-"+tenancy.Namespace+".golden"))
+				expected := JSONToProxyTemplate(t, golden.GetBytes(t, []byte(actual), name+"-"+tenancy.Partition+"-"+tenancy.Namespace+".golden"))
 
 				// sort routers on listener from golden file
 				expectedRouters := expected.ProxyState.Listeners[0].Routers
@@ -233,7 +233,7 @@ func TestBuildLocalApp_WithProxyConfiguration(t *testing.T) {
 				})
 
 				actual := protoToJSON(t, proxyTmpl)
-				expected := JSONToProxyTemplate(t, golden.GetBytes(t, actual, name+"-"+tenancy.Partition+"-"+tenancy.Namespace+".golden"))
+				expected := JSONToProxyTemplate(t, golden.GetBytes(t, []byte(actual), name+"-"+tenancy.Partition+"-"+tenancy.Namespace+".golden"))
 
 				// sort routers on listener from golden file
 				expectedRouters := expected.ProxyState.Listeners[0].Routers
