@@ -15,7 +15,10 @@ DEBUG=${DEBUG:-}
 XDS_TARGET=${XDS_TARGET:-server}
 
 # ENVOY_VERSION to run each test against
-ENVOY_VERSION=${ENVOY_VERSION:-"1.27.0"}
+if [[ -z "${ENVOY_VERSION:-}" ]]; then
+    echo "please set Envoy version via ENVOY_VERSION"
+    exit 1
+fi
 export ENVOY_VERSION
 
 export DOCKER_BUILDKIT=1
@@ -179,14 +182,6 @@ function start_consul {
     license=$(cat $CONSUL_LICENSE_PATH)
   fi
 
-  USE_RESOURCE_APIS=${USE_RESOURCE_APIS:-false}
-
-  experiments="experiments=[]"
-  # set up consul to run in V1 or V2 catalog mode
-  if [[ "${USE_RESOURCE_APIS}" == true ]]; then
-   experiments="experiments=[\"resource-apis\"]"
-  fi
-
   # We currently run these integration tests in two modes: one in which Envoy's
   # xDS sessions are served directly by a Consul server, and another in which it
   # goes through a client agent.
@@ -270,7 +265,6 @@ function start_consul {
       agent -dev -datacenter "${DC}" \
       -config-dir "/workdir/${DC}/consul" \
       -config-dir "/workdir/${DC}/consul-server" \
-      -hcl=${experiments} \
       -client "0.0.0.0" >/dev/null
   fi
 }
